"use strict";
const typescript_1 = require("@volar/typescript");
const vue = require("@vue/language-core");
const externalFiles = new WeakMap();
const init = (modules) => {
    const { typescript: ts } = modules;
    const pluginModule = {
        create(info) {
            const virtualFiles = vue.createVirtualFiles(vue.createLanguages(info.languageServiceHost.getCompilationSettings(), getVueCompilerOptions(), ts));
            (0, typescript_1.decorateLanguageService)(virtualFiles, info.languageService, true);
            (0, typescript_1.decorateLanguageServiceHost)(virtualFiles, info.languageServiceHost, ts, ['.vue']);
            const getCompletionsAtPosition = info.languageService.getCompletionsAtPosition.bind(info.languageService);
            info.languageService.getCompletionsAtPosition = (fileName, position, options) => {
                const result = getCompletionsAtPosition(fileName, position, options);
                if (result) {
                    result.entries = result.entries.filter(entry => entry.name.indexOf('__VLS_') === -1);
                }
                return result;
            };
            return info.languageService;
            function getVueCompilerOptions() {
                if (info.project.projectKind === ts.server.ProjectKind.Configured) {
                    const tsconfig = info.project.getProjectName();
                    return vue.createParsedCommandLine(ts, ts.sys, tsconfig).vueOptions;
                }
                else {
                    return vue.createParsedCommandLineByJson(ts, ts.sys, info.languageServiceHost.getCurrentDirectory(), {}).vueOptions;
                }
            }
        },
        getExternalFiles(project, updateLevel = -1) {
            if (
            // @ts-expect-error wait for TS 5.3
            updateLevel >= 1
                || !externalFiles.has(project)) {
                const oldFiles = externalFiles.get(project);
                const newFiles = (0, typescript_1.searchExternalFiles)(ts, project, ['.vue']);
                externalFiles.set(project, newFiles);
                if (oldFiles) {
                    refreshDiagnosticsIfNeeded(project, oldFiles, newFiles);
                }
            }
            return externalFiles.get(project);
        },
    };
    return pluginModule;
};
function refreshDiagnosticsIfNeeded(project, oldExternalFiles, newExternalFiles) {
    let dirty = oldExternalFiles.length !== newExternalFiles.length;
    if (!dirty) {
        const set = new Set(oldExternalFiles);
        for (const file of newExternalFiles) {
            if (!set.has(file)) {
                dirty = true;
                break;
            }
        }
    }
    if (dirty) {
        project.refreshDiagnostics();
    }
}
module.exports = init;
//# sourceMappingURL=index.js.map